==> haskell-raw-strings-qq-1.1-225-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-raw-strings-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 raw-strings-qq
version:              1.1
visibility:           public
id:                   raw-strings-qq-1.1-VApnGDkS2kGDwmKDL5Udj
key:                  raw-strings-qq-1.1-VApnGDkS2kGDwmKDL5Udj
license:              BSD-3-Clause
copyright:            (c) Mikhail Glushenkov 2013-2015
maintainer:           mikhail.glushenkov@gmail.com
author:               Mikhail Glushenkov
homepage:             https://github.com/23Skidoo/raw-strings-qq
synopsis:             Raw string literals for Haskell.
description:
    A quasiquoter for raw string literals - that is, string literals that don'\''t
    recognise the standard escape sequences (such as @\'\''\\n\'\''@). Basically, they
    make your code more readable by freeing you from the responsibility to
    escape backslashes. They are useful when working with regular expressions,
    DOS/Windows paths and markup languages (such as XML).

    See @examples/RawRegex.hs@ for a usage example.

category:             Text
abi:                  17feba10bdaa7b1e66a04038b4d72d26
exposed:              True
exposed-modules:      Text.RawString.QQ
import-dirs:          /usr/lib/ghc-9.2.8/site-local/raw-strings-qq-1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/raw-strings-qq-1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-raw-strings-qq
hs-libraries:         HSraw-strings-qq-1.1-VApnGDkS2kGDwmKDL5Udj
depends:              base-4.16.4.0 template-haskell-2.18.0.0
haddock-interfaces:
    /usr/share/doc/haskell-raw-strings-qq/html/raw-strings-qq.haddock

haddock-html:         /usr/share/doc/haskell-raw-strings-qq/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-raw-strings-qq-1.1-253.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-raw-strings-qq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 raw-strings-qq
version:              1.1
visibility:           public
id:                   raw-strings-qq-1.1-5c0fuHz8OpaCWras0U8UIC
key:                  raw-strings-qq-1.1-5c0fuHz8OpaCWras0U8UIC
license:              BSD-3-Clause
copyright:            (c) Mikhail Glushenkov 2013-2015
maintainer:           mikhail.glushenkov@gmail.com
author:               Mikhail Glushenkov
homepage:             https://github.com/23Skidoo/raw-strings-qq
synopsis:             Raw string literals for Haskell.
description:
    A quasiquoter for raw string literals - that is, string literals that don'\''t
    recognise the standard escape sequences (such as @\'\''\\n\'\''@). Basically, they
    make your code more readable by freeing you from the responsibility to
    escape backslashes. They are useful when working with regular expressions,
    DOS/Windows paths and markup languages (such as XML).

    See @examples/RawRegex.hs@ for a usage example.

category:             Text
abi:                  1a37a3e841e86b8530429fd144b2a96a
exposed:              True
exposed-modules:      Text.RawString.QQ
import-dirs:          /usr/lib/ghc-9.4.8/site-local/raw-strings-qq-1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/raw-strings-qq-1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/raw-strings-qq-1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-raw-strings-qq
hs-libraries:         HSraw-strings-qq-1.1-5c0fuHz8OpaCWras0U8UIC
depends:              base-4.17.2.1 template-haskell-2.19.0.0
haddock-interfaces:
    /usr/share/doc/haskell-raw-strings-qq/html/raw-strings-qq.haddock

haddock-html:         /usr/share/doc/haskell-raw-strings-qq/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
